@@ -1,10 +1,10 @@
 # django imports
 from django import template
-from django.contrib.contenttypes.models import ContentType
+from django.conf import settings
+from django.core.cache import cache
 
 # portlets imports
 import portlets.utils
-from portlets.models import PortletBlocking
 from portlets.models import Slot
 
 register = template.Library()
@@ -15,6 +15,18 @@ def portlet_slot(context, slot_name, instance=None):
     implements the ``get_parent_for_portlets`` method the portlets of the
     parent of the instance are also added.
     """
+    request = context.get("request")
+
+    # CACHE
+    content_type = instance.__class__.__name__.lower()
+    cache_key = "%s-portlets-%s-%s-%s-%s-%s" % (settings.CACHE_MIDDLEWARE_KEY_PREFIX,
+        content_type, instance.id, slot_name, request.user.id, context.get("CURRENT_LANGUAGE"))
+
+    rendered_portlets = cache.get(cache_key)
+
+    if rendered_portlets:
+        return { "portlets" : rendered_portlets }
+
     if instance is None:
         return { "portlets" : [] }
 
@@ -24,7 +36,7 @@ def portlet_slot(context, slot_name, instance=None):
         return { "portlets" : [] }
 
     # Get portlets for given instance
-    temp = portlets.utils.get_portlets(slot, instance)
+    temp = portlets.utils.get_portlets(instance, slot)
 
     # Get inherited portlets
     try:
@@ -47,7 +59,7 @@ def portlet_slot(context, slot_name, instance=None):
         if instance is None:
             break
 
-        parent_portlets = portlets.utils.get_portlets(slot, instance)
+        parent_portlets = portlets.utils.get_portlets(instance, slot)
         parent_portlets.reverse()
         for p in parent_portlets:
             if p not in temp:
@@ -57,4 +69,6 @@ def portlet_slot(context, slot_name, instance=None):
     for portlet in temp:
         rendered_portlets.append(portlet.render(context))
 
+    cache.set(cache_key, rendered_portlets)
+
     return { "portlets" : rendered_portlets }
\ No newline at end of file
