@@ -1,23 +1,83 @@
 # django imports
 from django.contrib.flatpages.models import FlatPage
-from django.contrib.auth.models import AnonymousUser
+from django.db import IntegrityError
 from django.test import TestCase
 
 # reviews imports
-import portlets.example.models
-import portlets.models
+from portlets.example.models import TextPortlet
+from portlets.models import PortletAssignment
+from portlets.models import PortletBlocking
+from portlets.models import PortletRegistration
+from portlets.models import Slot
 import portlets.utils
 
-class DummySession(object):
-    session_key = "42"
+class PortletsModelsTestCase(TestCase):
+    """Tests the models
+    """
+    def test_portlet(self):
+        """
+        """
+        text_portlet = TextPortlet.objects.create(title="Text")
+        self.assertEqual(text_portlet.title, "Text")
+        self.failIf(text_portlet.render().find("portlet-header") == -1)
+        self.failIf(text_portlet.form().as_p().find('id="id_title"') == -1)
 
-class DummyRequest(object):
-    def __init__(self, method="POST", user=None):
-        self.user = user
-        self.method = method
-        self.session = DummySession()
+    def test_slot(self):
+        """
+        """
+        slot = Slot.objects.create(name="Left")
+        self.assertEqual(slot.name, "Left")
 
-class UtilsTestCase(TestCase):
+    def test_portlet_registration(self):
+        """
+        """
+        portlet_registration = PortletRegistration.objects.create(
+            type = "textportlet",
+            name = "TextPortlet",
+        )
+
+        self.assertEqual(portlet_registration.type, "textportlet")
+        self.assertEqual(portlet_registration.name, "TextPortlet")
+        self.assertEqual(portlet_registration.active, True)
+
+        # add another portlet with other name
+        portlet_registration_2 = PortletRegistration.objects.create(
+            type = "textportlet_2",
+            name = "TextPortlet_2",
+        )
+
+    def test_portlet_assignment(self):
+        """
+        """
+        slot = Slot.objects.create(name="Left")
+        page = FlatPage.objects.create(url="/test/", title="Test")
+        portlet = TextPortlet.objects.create(title="Text")
+
+        portlet_assignment = PortletAssignment.objects.create(
+            slot = slot,
+            content = page,
+            portlet = portlet,
+        )
+
+        self.assertEqual(portlet_assignment.slot, slot)
+        self.assertEqual(portlet_assignment.content, page)
+        self.assertEqual(portlet_assignment.portlet, portlet)
+
+    def test_portlet_blocking(self):
+        """
+        """
+        slot = Slot.objects.create(name="Left")
+        page = FlatPage.objects.create(url="/test/", title="Test")
+
+        portlet_blocking = PortletBlocking.objects.create(
+            slot = slot,
+            content = page,
+        )
+
+        self.assertEqual(portlet_blocking.slot, slot)
+        self.assertEqual(portlet_blocking.content, page)
+
+class PortletsUtilsTestCase(TestCase):
     """Tests the methods of utils.py
     """
     def setUp(self):
@@ -27,15 +87,18 @@ class UtilsTestCase(TestCase):
         self.page = FlatPage.objects.create(url="/test/", title="Test")
 
         # Create a portlet
-        self.portlet = portlets.example.models.TextPortlet.objects.create(title="Text")
+        self.portlet = TextPortlet.objects.create(title="Text")
 
         # Create some slots
-        self.left_slot = portlets.models.Slot.objects.create(name="Left")
-        self.right_slot = portlets.models.Slot.objects.create(name="Right")
+        self.left_slot = Slot.objects.create(name="Left")
+        self.right_slot = Slot.objects.create(name="Right")
 
     def test_get_slots(self):
         """
         """
+        # We need to register the portlet first
+        portlets.utils.register_portlet(TextPortlet, "TextPortlet")
+        
         # At the beginning no slot has portlets
         slots = portlets.utils.get_slots(self.page)
         self.assertEqual(slots["has_portlets"], False)
@@ -45,7 +108,7 @@ class UtilsTestCase(TestCase):
         self.assertEqual(slots["items"][1]["portlets"], [])
 
         # Assigning the text portlet to the left slot of the page
-        portlets.models.PortletAssignment.objects.create(
+        PortletAssignment.objects.create(
             slot=self.left_slot, content=self.page, portlet=self.portlet, position=1)
 
         slots = portlets.utils.get_slots(self.page)
@@ -56,10 +119,10 @@ class UtilsTestCase(TestCase):
         self.assertEqual(slots["items"][1]["portlets"], [])
 
         # Create another portlet ...
-        portlet_2 = portlets.example.models.TextPortlet.objects.create(title="Text 2")
+        portlet_2 = TextPortlet.objects.create(title="Text 2")
 
         # ... and assign it also to the left slot of the page
-        portlets.models.PortletAssignment.objects.create(
+        PortletAssignment.objects.create(
             slot=self.left_slot, content=self.page, portlet=portlet_2, position=2)
 
         slots = portlets.utils.get_slots(self.page)
@@ -71,10 +134,10 @@ class UtilsTestCase(TestCase):
         self.assertEqual(slots["items"][1]["portlets"], [])
 
         # Create another portlet ...
-        portlet_3 = portlets.example.models.TextPortlet.objects.create(title="Text 3")
+        portlet_3 = TextPortlet.objects.create(title="Text 3")
 
         # ... and assign it the right slot of the page
-        portlets.models.PortletAssignment.objects.create(
+        PortletAssignment.objects.create(
             slot=self.right_slot, content=self.page, portlet=portlet_3, position=1)
 
         slots = portlets.utils.get_slots(self.page)
@@ -89,30 +152,30 @@ class UtilsTestCase(TestCase):
         """
         """
         # At the beginning no slot has portlets
-        result = portlets.utils.has_portlets(self.left_slot, self.page)
+        result = portlets.utils.has_portlets(self.page, self.left_slot)
         self.assertEqual(result, False)
 
-        result = portlets.utils.has_portlets(self.right_slot, self.page)
+        result = portlets.utils.has_portlets(self.page, self.right_slot)
         self.assertEqual(result, False)
 
         # Assigning the text portlet to the left slot of the page
-        portlets.models.PortletAssignment.objects.create(
+        PortletAssignment.objects.create(
             slot=self.left_slot, content=self.page, portlet=self.portlet, position=1)
 
-        result = portlets.utils.has_portlets(self.left_slot, self.page)
+        result = portlets.utils.has_portlets(self.page, self.left_slot)
         self.assertEqual(result, True)
 
-        result = portlets.utils.has_portlets(self.right_slot, self.page)
+        result = portlets.utils.has_portlets(self.page, self.right_slot)
         self.assertEqual(result, False)
 
         # Assigning the text portlet to the right slot of the page
-        portlets.models.PortletAssignment.objects.create(
+        PortletAssignment.objects.create(
             slot=self.right_slot, content=self.page, portlet=self.portlet, position=1)
 
-        result = portlets.utils.has_portlets(self.left_slot, self.page)
+        result = portlets.utils.has_portlets(self.page, self.left_slot)
         self.assertEqual(result, True)
 
-        result = portlets.utils.has_portlets(self.right_slot, self.page)
+        result = portlets.utils.has_portlets(self.page, self.right_slot)
         self.assertEqual(result, True)
 
     def test_register_portlets(self):
@@ -123,12 +186,12 @@ class UtilsTestCase(TestCase):
         self.assertEqual(result, {})
 
         # Register the TextPortlet
-        portlets.utils.register_portlet(portlets.example.models.TextPortlet, "TextPortlet")
+        portlets.utils.register_portlet(TextPortlet, "TextPortlet")
         result = portlets.utils.get_registered_portlets()
         self.assertEqual(result, {u"textportlet" : u"TextPortlet"})
 
         # Unregister the TextPortlet
-        portlets.utils.unregister_portlet(portlets.example.models.TextPortlet)
+        portlets.utils.unregister_portlet(TextPortlet)
         result = portlets.utils.get_registered_portlets()
         self.assertEqual(result, {})
 
@@ -136,11 +199,11 @@ class UtilsTestCase(TestCase):
         """
         """
         # Assigning the text portlet to the left slot of the page
-        portlets.models.PortletAssignment.objects.create(
+        PortletAssignment.objects.create(
             slot=self.left_slot, content=self.page, portlet=self.portlet, position=1)
 
         # Assigning the text portlet to the left slot of the page
-        portlets.models.PortletAssignment.objects.create(
+        PortletAssignment.objects.create(
             slot=self.right_slot, content=self.page, portlet=self.portlet, position=1)
 
         result = portlets.utils.is_blocked(self.page, self.left_slot)
@@ -148,9 +211,9 @@ class UtilsTestCase(TestCase):
 
         result = portlets.utils.is_blocked(self.page, self.right_slot)
         self.assertEqual(result, False)
-        
+
         # Blocking the left slot of the page
-        portlets.models.PortletBlocking.objects.create(slot=self.left_slot, content=self.page)
+        PortletBlocking.objects.create(slot=self.left_slot, content=self.page)
 
         result = portlets.utils.is_blocked(self.page, self.left_slot)
         self.assertEqual(result, True)
@@ -159,11 +222,10 @@ class UtilsTestCase(TestCase):
         self.assertEqual(result, False)
 
         # Blocking the left right of the page
-        portlets.models.PortletBlocking.objects.create(slot=self.right_slot, content=self.page)
+        PortletBlocking.objects.create(slot=self.right_slot, content=self.page)
 
         result = portlets.utils.is_blocked(self.page, self.left_slot)
         self.assertEqual(result, True)
 
         result = portlets.utils.is_blocked(self.page, self.right_slot)
         self.assertEqual(result, True)
-        
\ No newline at end of file
